@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 15.0 Debian package creator
-# Release 2018-08-13
+# DaVinci Resolve 15.0.1 Debian package creator
+# Release 2018-09-03
 # By Daniel Tufvesson
 #
 
@@ -97,7 +97,7 @@ extract_zip() {
 }
 
 # Setup variables
-RESOLVE_VERSION=15.0
+RESOLVE_VERSION=15.0.1
 DEB_STEPPING=1
 case $1 in
     studio)
@@ -148,6 +148,7 @@ create_directory ${RESOLVE_BASE_DIR}/logs
 create_directory ${RESOLVE_BASE_DIR}/scripts
 create_directory ${RESOLVE_BASE_DIR}/.LUT
 create_directory ${RESOLVE_BASE_DIR}/.license
+create_directory ${RESOLVE_BASE_DIR}/.crashreport
 create_directory ${RESOLVE_BASE_DIR}/DolbyVision
 create_directory ${RESOLVE_BASE_DIR}/Fairlight
 create_directory ${RESOLVE_BASE_DIR}/Media
@@ -181,6 +182,7 @@ copy_object ${UNPACK_DIR}/rsf/Control ${RESOLVE_BASE_DIR}
 copy_object ${UNPACK_DIR}/rsf/DV_Resolve.png ${RESOLVE_BASE_DIR}/graphics
 copy_object ${UNPACK_DIR}/rsf/default-config-linux.dat ${RESOLVE_BASE_DIR}/configs/config.dat-pkg-default
 copy_object ${UNPACK_DIR}/rsf/log-conf.xml ${RESOLVE_BASE_DIR}/configs/log-conf.xml-pkg-default
+copy_object ${UNPACK_DIR}/rsf/default_cm_config.bin ${RESOLVE_BASE_DIR}/DolbyVision/config.bin-pkg-default
 
 # Extract archives
 extract_tgz ${UNPACK_DIR}/panels/libusb-1.0.tgz ${RESOLVE_BASE_DIR}/bin
@@ -200,7 +202,6 @@ extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/sonyrawdev-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/smdk-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/sstp-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/sxavc-rt-linux-x86_64.tgz
-rm -f ${RESOLVE_BASE_DIR}/libs/libcuda.so*
 
 # Create udev rules
 create_directory ${DEB_DIR}/lib/udev/rules.d
@@ -244,6 +245,7 @@ test -e /usr/lib/x86_64-linux-gnu/libssl.so.1.0.0 && ln -sf /usr/lib/x86_64-linu
 test -e /lib/x86_64-linux-gnu/libssl.so.1.0.0 && ln -sf /lib/x86_64-linux-gnu/libssl.so.1.0.0 /opt/resolve/libs/libssl.so.10
 test -e /opt/resolve/configs/config.dat || cp /opt/resolve/configs/config.dat-pkg-default /opt/resolve/configs/config.dat
 test -e /opt/resolve/configs/log-conf.xml || cp /opt/resolve/configs/log-conf.xml-pkg-default /opt/resolve/configs/log-conf.xml
+test -e /opt/resolve/DolbyVision/config.bin || cp /opt/resolve/DolbyVision/config.bin-pkg-default /opt/resolve/DolbyVision/config.bin
 chmod -R a+rw /opt/resolve/configs
 chmod -R a+rw /opt/resolve/Media
 chmod -R a+rw /opt/resolve/DolbyVision
@@ -254,6 +256,7 @@ chmod -R a+rw /opt/resolve/"Resolve Disk Database"
 chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.LUT
 chmod -R a+rw /opt/resolve/.license
+chmod -R a+rw /opt/resolve/.crashreport
 chmod -R a+rw /opt/resolve/logs
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
